---
name: Bug Report
about: Create a report to help us improve
title: "[BUG]"
labels: bug

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behaviour:
1.
2.
3.
4.

**Expected behavior**
A clear and concise description of what you expected to happen.

**Environment:**
 - OS: [e.g. Ubuntu 16.04]
 - Python Version [e.g. 3.6]
 - autopew Version [e.g. 0.1.0]

**Additional Context**
Add any other context about the problem here. If applicable, add screenshots to help explain your problem.
